
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef viam_MSG_LIB_H
#define viam_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "viamType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  VIAM_MBOX_NAME                  genomInstanceName("viam")

#define  VIAM_MAX_RQST_SIZE              1156

#define  VIAM_MBOX_RQST_SIZE       \
 (BUF_SIZE(VIAM_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  VIAM_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  VIAM_MAX_REPLY_SIZE             644

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  VIAM_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(VIAM_MAX_REPLY_SIZE) \
   + BUF_SIZE(VIAM_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define VIAM_INIT_RQST 0
#define VIAM_CONFIGURE_RQST 1
#define VIAM_RESET_RQST 2
#define VIAM_DRIVERLOAD_RQST 3
#define VIAM_BUSPRINT_RQST 4
#define VIAM_BANKCREATE_RQST 5
#define VIAM_CAMERACREATE_RQST 6
#define VIAM_BANKADDCAMERA_RQST 7
#define VIAM_PUSHFORMATFILTER_RQST 8
#define VIAM_UPDATEFORMATFILTER_RQST 9
#define VIAM_PUSHGEOFILTER_RQST 10
#define VIAM_UPDATEGEOFILTER_RQST 11
#define VIAM_PUSHLUMFILTER_RQST 12
#define VIAM_UPDATELUMFILTER_RQST 13
#define VIAM_PUSHCOLORFILTER_RQST 14
#define VIAM_UPDATECOLORFILTER_RQST 15
#define VIAM_PUSHIMPROCFILTER_RQST 16
#define VIAM_UPDATEIMPROCFILTER_RQST 17
#define VIAM_PUSHMISCFILTER_RQST 18
#define VIAM_UPDATEMISCFILTER_RQST 19
#define VIAM_FILTERLIST_RQST 20
#define VIAM_FILTERGETCAP_RQST 21
#define VIAM_CAMERALISTHWMODES_RQST 22
#define VIAM_CAMERASETHWMODE_RQST 23
#define VIAM_ACQUIRE_RQST 24
#define VIAM_STOP_RQST 25
#define VIAM_DISPLAY_RQST 26
#define VIAM_CALIBRATE_RQST 27
#define VIAM_CALIBRATIONIO_RQST 28
#define VIAM_SAVE_RQST 29
#define VIAM_ABORT_RQST 30


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS viamClientInit (CLIENT_ID *pClientId);

STATUS viamClientEnd (CLIENT_ID clientId);

int viamAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int viamAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int viamAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS viamInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int viamInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int viamInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int viamInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS viamConfigureRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamId *(in_name),
					 int replyTimeOut);

extern int viamConfigureReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int viamConfigureRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamId *(in_name), 
					
					int *activity, int *bilan);

extern int viamConfigureRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamId *(in_name), 
					
					int *activity,
					int *bilan);




extern STATUS viamResetRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int viamResetReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int viamResetRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int viamResetRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS viamDriverLoadRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamId *(in_name),
					 int replyTimeOut);

int viamDriverLoadReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamDriverLoadRqstAndRcv (CLIENT_ID clientId, 
				 ViamId *(in_name), 
				 
				 int *bilan);




extern STATUS viamBusPrintRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int viamBusPrintReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamBusPrintRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS viamBankCreateRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamBankCreate *(in_bank_create),
					 int replyTimeOut);

int viamBankCreateReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamBankCreateRqstAndRcv (CLIENT_ID clientId, 
				 ViamBankCreate *(in_bank_create), 
				 
				 int *bilan);




extern STATUS viamCameraCreateRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamCameraCreate *(in_camera_create),
					 int replyTimeOut);

int viamCameraCreateReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamCameraCreateRqstAndRcv (CLIENT_ID clientId, 
				 ViamCameraCreate *(in_camera_create), 
				 
				 int *bilan);




extern STATUS viamBankAddCameraRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamBankAddCamera *(in_bank_add_camera),
					 int replyTimeOut);

int viamBankAddCameraReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamBankAddCameraRqstAndRcv (CLIENT_ID clientId, 
				 ViamBankAddCamera *(in_bank_add_camera), 
				 
				 int *bilan);




extern STATUS viamPushFormatFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamFmtFilter *(in_fmtfilter),
					 int replyTimeOut);

int viamPushFormatFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamPushFormatFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamFmtFilter *(in_fmtfilter), 
				 
				 int *bilan);




extern STATUS viamUpdateFormatFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamUFmtFilter *(in_ufmtfilter),
					 int replyTimeOut);

int viamUpdateFormatFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamUpdateFormatFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamUFmtFilter *(in_ufmtfilter), 
				 
				 int *bilan);




extern STATUS viamPushGeoFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamGeoFilter *(in_geofilter),
					 int replyTimeOut);

int viamPushGeoFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamPushGeoFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamGeoFilter *(in_geofilter), 
				 
				 int *bilan);




extern STATUS viamUpdateGeoFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamUGeoFilter *(in_ugeofilter),
					 int replyTimeOut);

int viamUpdateGeoFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamUpdateGeoFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamUGeoFilter *(in_ugeofilter), 
				 
				 int *bilan);




extern STATUS viamPushLumFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamLumFilter *(in_lumfilter),
					 int replyTimeOut);

int viamPushLumFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamPushLumFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamLumFilter *(in_lumfilter), 
				 
				 int *bilan);




extern STATUS viamUpdateLumFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamULumFilter *(in_ulumfilter),
					 int replyTimeOut);

int viamUpdateLumFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamUpdateLumFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamULumFilter *(in_ulumfilter), 
				 
				 int *bilan);




extern STATUS viamPushColorFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamColorFilter *(in_colorfilter),
					 int replyTimeOut);

int viamPushColorFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamPushColorFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamColorFilter *(in_colorfilter), 
				 
				 int *bilan);




extern STATUS viamUpdateColorFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamUColorFilter *(in_ucolorfilter),
					 int replyTimeOut);

int viamUpdateColorFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamUpdateColorFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamUColorFilter *(in_ucolorfilter), 
				 
				 int *bilan);




extern STATUS viamPushImProcFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamPxFilter *(in_pxfilter),
					 int replyTimeOut);

int viamPushImProcFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamPushImProcFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamPxFilter *(in_pxfilter), 
				 
				 int *bilan);




extern STATUS viamUpdateImProcFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamUPxFilter *(in_upxfilter),
					 int replyTimeOut);

int viamUpdateImProcFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamUpdateImProcFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamUPxFilter *(in_upxfilter), 
				 
				 int *bilan);




extern STATUS viamPushMiscFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamMiscFilter *(in_miscfilter),
					 int replyTimeOut);

int viamPushMiscFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamPushMiscFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamMiscFilter *(in_miscfilter), 
				 
				 int *bilan);




extern STATUS viamUpdateMiscFilterRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamUMiscFilter *(in_umiscfilter),
					 int replyTimeOut);

int viamUpdateMiscFilterReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamUpdateMiscFilterRqstAndRcv (CLIENT_ID clientId, 
				 ViamUMiscFilter *(in_umiscfilter), 
				 
				 int *bilan);




extern STATUS viamFilterListRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamId *(in_name),
					 int replyTimeOut);

extern int viamFilterListReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ViamFilterList *(out_filterlist),
				      int *activity, int *bilan);


extern int viamFilterListRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamId *(in_name), 
					ViamFilterList *(out_filterlist),
					int *activity, int *bilan);

extern int viamFilterListRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamId *(in_name), 
					ViamFilterList *(out_filterlist),
					int *activity,
					int *bilan);




extern STATUS viamFilterGetCapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamFilterGetCap *(in_filtergetcap),
					 int replyTimeOut);

extern int viamFilterGetCapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ViamFilterCap *(out_filtercap),
				      int *activity, int *bilan);


extern int viamFilterGetCapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamFilterGetCap *(in_filtergetcap), 
					ViamFilterCap *(out_filtercap),
					int *activity, int *bilan);

extern int viamFilterGetCapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamFilterGetCap *(in_filtergetcap), 
					ViamFilterCap *(out_filtercap),
					int *activity,
					int *bilan);




extern STATUS viamCameraListHWModesRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamHWModeListOffset *(in_hwmodeoffset),
					 int replyTimeOut);

extern int viamCameraListHWModesReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ViamHWModeList *(out_hwmodes),
				      int *activity, int *bilan);


extern int viamCameraListHWModesRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamHWModeListOffset *(in_hwmodeoffset), 
					ViamHWModeList *(out_hwmodes),
					int *activity, int *bilan);

extern int viamCameraListHWModesRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamHWModeListOffset *(in_hwmodeoffset), 
					ViamHWModeList *(out_hwmodes),
					int *activity,
					int *bilan);




extern STATUS viamCameraSetHWModeRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamHWMode *(in_hwmode),
					 int replyTimeOut);

int viamCameraSetHWModeReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamCameraSetHWModeRqstAndRcv (CLIENT_ID clientId, 
				 ViamHWMode *(in_hwmode), 
				 
				 int *bilan);




extern STATUS viamAcquireRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamAcquire *(in_acquire),
					 int replyTimeOut);

extern int viamAcquireReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      ViamAcquire *(out_acquire),
				      int *activity, int *bilan);


extern int viamAcquireRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamAcquire *(in_acquire), 
					ViamAcquire *(out_acquire),
					int *activity, int *bilan);

extern int viamAcquireRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamAcquire *(in_acquire), 
					ViamAcquire *(out_acquire),
					int *activity,
					int *bilan);




extern STATUS viamStopRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamId *(in_name),
					 int replyTimeOut);

extern int viamStopReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int viamStopRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamId *(in_name), 
					
					int *activity, int *bilan);

extern int viamStopRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamId *(in_name), 
					
					int *activity,
					int *bilan);




extern STATUS viamDisplayRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamDisplay *(in_display),
					 int replyTimeOut);

extern int viamDisplayReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int viamDisplayRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamDisplay *(in_display), 
					
					int *activity, int *bilan);

extern int viamDisplayRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamDisplay *(in_display), 
					
					int *activity,
					int *bilan);




extern STATUS viamCalibrateRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ViamCalibrate *(in_calibrate),
					 int replyTimeOut);

extern int viamCalibrateReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      double *(out_precision),
				      int *activity, int *bilan);


extern int viamCalibrateRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ViamCalibrate *(in_calibrate), 
					double *(out_precision),
					int *activity, int *bilan);

extern int viamCalibrateRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ViamCalibrate *(in_calibrate), 
					double *(out_precision),
					int *activity,
					int *bilan);




extern STATUS viamCalibrationIORqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamCalibrationIO *(in_calibrationio),
					 int replyTimeOut);

int viamCalibrationIOReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamCalibrationIORqstAndRcv (CLIENT_ID clientId, 
				 ViamCalibrationIO *(in_calibrationio), 
				 
				 int *bilan);




extern STATUS viamSaveRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ViamSave *(in_save),
					 int replyTimeOut);

int viamSaveReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int viamSaveRqstAndRcv (CLIENT_ID clientId, 
				 ViamSave *(in_save), 
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* viam_MSG_LIB_H */

